#!/usr/bin/ruby

require 'json'
require 'socket'
require 'syslog/logger'
require 'date'

$log = Syslog::Logger.new 'scratch_stats.rb'

$hostname = Socket.gethostname

$time_now_sec = Time.now.to_i

$running_job = {}

jobs=`momctl -d0 | grep RUNNING`

jobs.each_line do |line|
  line = line.sub(/] .*/, '').chomp
  line = line.sub(/job\[/, 'job_')
  $running_job[line] = 'Yes'
end

ARGV.each do |scratchdir|

  $sizes_scratch = {}

  if scratchdir == nil or ! File.directory?(scratchdir) 
    $log.error("Directory '#{scratchdir}' does not exist")
    next
  end

  Dir.foreach(scratchdir) do |user|
    next if user == '.' or user == '..'
    next if ! File.directory?("#{scratchdir}/#{user}")
    ## process user
    Dir.foreach("#{scratchdir}/#{user}") do |job|
      next if job == '.' or job == '..'
      next if job !~ /^job/
      size = `du -sk '#{scratchdir}/#{user}/#{job}'`.chomp
      files = `find '#{scratchdir}/#{user}/#{job}' | wc -l`.chomp.to_i
      size = size.sub(/[ \t].*/, '').to_i
      running = $running_job[job]
      if running == nil
        running = 'No'
      end
      if size > 4096
        $sizes_scratch[job] = { 'user' => user, 'size' => size*1024, 'files' => files, 'running' => running }
      end
    end  
  end

  $output = []

  $sizes_scratch.each do |k, v|
    $output << {'job' => k, 'user' => v['user'], 'size' => v['size'], 'user_t' => v['user'], 'dir' => scratchdir,
                'files' => v['files'], 'name' => 'scratch_stats', 'running' =>  v['running'], 'host' => $hostname,
                'job_t' => k, 'wid' => 'n/a', 'time' => $time_now_sec}
  end

  scratchdir_name = scratchdir.gsub(/\//, '')

  f = File.new("/var/tmp/scratch_stats_#{scratchdir_name}.json.new", "w", 0644)
  f.write(JSON.pretty_generate($output))
  f.close

  File.rename("/var/tmp/scratch_stats_#{scratchdir_name}.json.new", "/var/tmp/scratch_stats_#{scratchdir_name}.json")
end
